from .account import Account  # noqa
from .authentication import Google, GoogleOAuth2, Outlook  # noqa
from .flag import Flag  # noqa
from .mailbox import Mailbox  # noqa
from .message import Message  # noqa

__version__ = "0.4.0"
